@@ -15,14 +15,6 @@
 #' @param arrival_time \code{POSIXct}. Specifies teh desired time of arrival. Note you can
 #' only specify one of \code{arrival_time} or \code{departure_time}, not both.
 #' If both are supplied, \code{departure_time} will be used.
-#' @param waypoints list of waypoints, expressed as either a \code{vector} of
-#' lat/lon coordinates, or a \code{string} address to be geocoded. Only available
-#' for transit, walking or bicycling modes. List elements must be named either
-#' 'stop' or 'via', where 'stop' is used to indicate a stopover for a waypoint,
-#' and 'via' will not stop at the waypoint.
-#' See \url{https://developers.google.com/maps/documentation/directions/intro#Waypoints} for details
-#' @param alternatives \code{logical} If set to true, specifies that the Directions service
-#' may provide more than one route alternative in the response
 #' @param avoid \code{character} vector stating which features should be avoided.
 #' One of 'tolls', 'highways', 'ferries' or 'indoor'
 #' @param units \code{string} metric or imperial. Note: Only affects the text displayed
@@ -39,10 +31,8 @@
 #' See the list of supported languages: \url{https://developers.google.com/maps/faq#using-google-maps-apis}
 #' If no langauge is supplied, the service will attempt to use the language of
 #' the domain from which the request was sent
-#' @param region \code{string}. Specifies the region code, specified as a ccTLD ("top-level domain").
-#' See region basing for details \url{https://developers.google.com/maps/documentation/directions/intro#RegionBiasing}
 #' @param key \code{string}. A valid Google Developers Distance API key
-#' @param simplify \code{logical}. Indicates if the returned JSON should be coerced into a list
+#' @param simplify \code{logical} - TRUE indicates the returned JSON will be coerced into a list. FALSE indicates the returend JSON will be returned as a string
 #' @param curl_proxy a curl proxy object
 #' @return Either list or JSON string of the distance between origins and destinations
 #' @examples
@@ -63,15 +53,12 @@ google_distance <- function(origins,
                             mode = c('driving','walking','bicycling','transit'),
                             departure_time = NULL,
                             arrival_time = NULL,
-                            waypoints = NULL,
-                            alternatives = FALSE,
                             avoid = NULL,
                             units = c("metric", "imperial"),
                             traffic_model = NULL,
                             transit_mode = NULL,
                             transit_routing_preference = NULL,
                             language = NULL,
-                            region = NULL,
                             key,
                             simplify = TRUE,
                             curl_proxy = NULL){
@@ -83,16 +70,16 @@ google_distance <- function(origins,
                 mode,
                 departure_time,
                 arrival_time,
-                waypoints,
+                waypoints = NULL,
                 optimise_waypoints = FALSE,
-                alternatives,
+                alternatives = FALSE,
                 avoid,
                 units,
                 traffic_model,
                 transit_mode,
                 transit_routing_preference,
                 language,
-                region,
+                region = NULL,
                 key,
                 simplify,
                 curl_proxy)
