@@ -25,4 +25,13 @@ test_that("incorrect encoded string throws error",{
 
 })
 
+test_that("polyline encoded correctly", {
+
+  expect_equal(
+    encode_pl(lat = c(38.5, 40.7, 43.252), lon = c(-120.2, -120.95, -126.453)),
+    "_p~iF~ps|U_ulLnnqC_mqNvxq`@"
+  )
+
+})
+
 
